@@ -9,6 +9,10 @@
 #'
 #' @example examples/colors.R
 ax_colors_manual <- function(ax, values) {
+  if (!inherits(ax, "apexcharter"))
+    stop("ax_colors_manual: ax must be an apexcharter object", call. = FALSE)
+  ax$x$colors_manual <- values
+  ax$x$ax_opts$colors <- NULL
   groups <- get_groups(ax)
   values <- validate_values(values, groups)
   ax_colors(ax = ax, values$val)
@@ -34,7 +38,7 @@ get_groups <- function(ax) {
   if (!inherits(ax, "apexcharter"))
     stop("ax must be an apexcharter htmlwidget")
   if (is.null(ax$x$ax_opts$series))
-    stop("ax must have a series of data")
+    stop("ax must have a serie of data")
   groups <- lapply(ax$x$ax_opts$series, `[[`, "name")
   groups <- unlist(groups)
   as.character(groups)
